@@ -139,6 +139,10 @@ def export_pvalues(project, out: str):
                 d['pval'].append(pval_alt)
     for file, d in res.items():
         folder, file = os.path.split(file)
+        if os.name != 'nt':
+            folder = folder[1:] if folder[0] == '/' else folder
+        elif folder[1:3] in (':/', ':\\'):
+            folder = folder[3:].lstrip('/\\')
         folder = os.path.join(out, folder)
         file = get_name(file) + '.pvalue.tsv'
         file = os.path.join(folder, file)
